aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/ruby/ext/grpc/rb_event.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ruby/ext/grpc/rb_event.h')
-rw-r--r--src/ruby/ext/grpc/rb_event.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ruby/ext/grpc/rb_event.h b/src/ruby/ext/grpc/rb_event.h
index 3105934b11..b145148bd5 100644
--- a/src/ruby/ext/grpc/rb_event.h
+++ b/src/ruby/ext/grpc/rb_event.h
@@ -37,12 +37,12 @@
#include <ruby.h>
#include <grpc/grpc.h>
-/* rb_cEvent is the Event class whose instances proxy grpc_event. */
-extern VALUE rb_cEvent;
+/* grpc_cEvent is the Event class whose instances proxy grpc_event. */
+extern VALUE grpc_cEvent;
-/* rb_cEventError is the ruby class that acts the exception thrown during rpc
+/* grpc_eEventError is the ruby class that acts the exception thrown during rpc
event processing. */
-extern VALUE rb_eEventError;
+extern VALUE grpc_eEventError;
/* Used to create new ruby event objects */
VALUE grpc_rb_new_event(grpc_event *ev);